/**
 * $Id: StackTraceAspect.aj,v 1.1 2011/12/22 17:15:08 oboehm Exp $
 *
 * Copyright (c) 2008 by Oliver Boehm
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express orimplied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * (c)reated 14.09.2008 by oliver (ob@oasd.de)
 */
package patterntesting.check.ct;

import patterntesting.annotation.check.ct.*;

/**
 * Using e.printStacktrace() is not a good idea. So this aspect together with
 * AbstractStackTraceAspect will print a warning for this call.
 *
 * @author <a href="boehm@javatux.de">oliver</a>
 * @since 14.09.2008
 * @version $Revision: 1.1 $
 *
 * @see AbstractStackTraceAspect
 */
public aspect StackTraceAspect extends AbstractStackTraceAspect {

    /**
     * Look at the whole code to find e.printStacktrace()
     */
    public pointcut applicationCode() :  within(*..*);

    /**
     * You can suppress the warning with "@SuppressStackTraceWarning".
     */
    public pointcut allowedCode() :
        within(@SuppressStackTraceWarning *)
        || withincode(@SuppressStackTraceWarning *..*.new(..))
        || withincode(@SuppressStackTraceWarning * *..*.*(..))
        ;
	
}

/**
 * $Log: StackTraceAspect.aj,v $
 * Revision 1.1  2011/12/22 17:15:08  oboehm
 * directory structure adapted to preferences of maven-aspectj-plugin
 *
 * Revision 1.1  2010/01/05 16:44:14  oboehm
 * begin with 1.0
 *
 * Revision 1.3  2009/12/20 17:30:35  oboehm
 * trailing spaces removed
 *
 * Revision 1.2  2009/03/26 10:19:11  oboehm
 * annotations for patterntesting-check-ct moved
 * to patterntesting.annotation.check.ct
 *
 * Revision 1.1  2009/03/25 22:02:27  oboehm
 * initial setup
 *
 * $Source: /cvsroot/patterntesting/PatternTesting10/patterntesting-check-ct/src/main/aspect/patterntesting/check/ct/StackTraceAspect.aj,v $
 */
